/*
 * $Id: dummy.c,v 1.2 2001/08/14 06:11:41 thep Exp $
 * dummy.c - a dummy source to let sub-libraries link
 * Created: 2001-06-12
 * Author:  Theppitak Karoonboonyanan
 */

/* ANSI C forbids an empty source file */
static char dummy;

